@@ -27,29 +27,38 @@ import shutil
 import popen2
 
 from zope.testing import doctest
+from zc.buildout import buildout
 
 current_dir = os.path.abspath(os.path.dirname(__file__))
 
+from os.path import join
+
+def sh(cmd):
+    os.system(cmd)
+
+def python(cmd):
+    os.system('%s %s' % (sys.executable, cmd))
+
 def rmdir(*args):
     dirname = os.path.join(*args)
     if os.path.isdir(dirname):
         shutil.rmtree(dirname)
 
-def sh(cmd):
-    """XXX this is intrusive
-    -> need to be root to install python packages
-    in some cases
-    """
-    _cmd = cmd
-    print cmd
-    if _cmd.startswith('python') or \
-       _cmd.startswith('paster'):
-        _cmd = execdir + os.path.sep + cmd
-    # launch command 2 times to see what append and be able to test in doc tests
-    os.system(_cmd)
-    child_stdout_and_stderr, child_stdin = popen2.popen4(_cmd)
-    child_stdin.close()
-    print child_stdout_and_stderr.read()
+def paster(cmd):
+    print "paster %s" % cmd
+    from paste.script import command
+    args = cmd.split()
+    options, args = command.parser.parse_args(args)
+    options.base_parser = command.parser
+    command.system_plugins.extend(options.plugins or [])
+    commands = command.get_commands()
+    command_name = args[0]
+    if command_name not in commands:
+        command = command.NotFoundCommand
+    else:
+        command = commands[command_name].load()
+    runner = command(command_name)
+    runner.run(args[1:])
 
 def ls(*args):
     dirname = os.path.join(*args)
@@ -63,11 +72,17 @@ def ls(*args):
     else:
         print 'No directory named %s' % dirname
 
+def build(cfg_file):
+    dirname = os.path.dirname(cfg_file)
+    os.chdir(dirname)
+    builder = buildout.Buildout(cfg_file, {})
+    builder.bootstrap(())
+    builder.install(())
+
 def cd(*args):
     dirname = os.path.join(*args)
     os.chdir(dirname)
 
-
 def config(filename):
     return os.path.join(current_dir, filename)
 
